ps.plone.mls
============

`Propertyshelf`_ MLS Plone Embedding.

Read the full documentation at `<http://psplonemls.readthedocs.org/en/latest>`_.


Mostly Harmless
---------------

.. image:: https://travis-ci.org/propertyshelf/ps.plone.mls.png?branch=master
    :target: http://travis-ci.org/propertyshelf/ps.plone.mls
    :alt: Travis CI status

.. image:: https://coveralls.io/repos/propertyshelf/ps.plone.mls/badge.png?branch=master
    :target: https://coveralls.io/r/propertyshelf/ps.plone.mls?branch=master
    :alt: Coveralls status

.. image:: https://badge.fury.io/py/ps.plone.mls.png
    :target: http://badge.fury.io/py/ps.plone.mls
    :alt: Fury Python

.. image:: https://badge.fury.io/gh/propertyshelf%2Fps.plone.mls.png
    :target: http://badge.fury.io/gh/propertyshelf%2Fps.plone.mls
    :alt: Fury Github


.. _`Propertyshelf`: http://propertyshelf.com
